@@ -1,3 +1,5 @@
+( cd opt/kde/share/doc/HTML/de/kugar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kugar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kword ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/koffice ; rm -rf common )
